@@ -13,7 +13,7 @@ NumericMatrix hellinger_dist(NumericMatrix x,const bool sqr){
   mat xx(x.begin(),nrw,ncl,false);
   NumericMatrix f(ncl,ncl);
   colvec xv(nrw);
-  register double a;
+  double a;
   int i,j;
   if(sqr)
     for(i=0;i<ncl-1;++i){
