@@ -15,7 +15,7 @@ NumericMatrix minkowski_dist(NumericMatrix x,const double p){
   mat xx(x.begin(),nrw,ncl,false);
   NumericMatrix f(ncl,ncl);
   colvec xv(nrw);
-  register double a;
+  double a;
   int i,j;
   for(i=0;i<ncl-1;++i){
     xv=xx.col(i);
